/*
 * Copyright 2010 by Kappich Systemberatung Aachen
 * 
 * This file is part of de.bsvrz.dav.dav.
 * 
 * de.bsvrz.dav.dav is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.dav.dav is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.dav.dav; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package de.bsvrz.dav.dav.util.accessControl;

import de.bsvrz.dav.daf.communication.lowLevel.telegrams.BaseSubscriptionInfo;
import de.bsvrz.dav.daf.main.config.Aspect;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.ConfigurationArea;
import de.bsvrz.dav.daf.main.config.ObjectSetType;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.dav.daf.main.config.SystemObjectType;

/**
 * Interface, das ein BenutzerInfo-Objekt reprsentiert, das nach verschiedenen Berechtigungen gefragt werden kann.
 *
 * @author Kappich Systemberatung
 * @version $Revision: 11671 $
 */
public interface UserInfo {

	/**
	 * Prft, ob die angegebenen Daten beim Datenverteiler angemeldet werden drfen.
	 *
	 * @param info  Daten-Anmeldungs-Informationen
	 * @param state <ul><li>state 0: Als Sender</li> <li>1: Als Empfnger</li> <li>2: Als Quelle</li> <li>3: Als Senke</li></ul>
	 *
	 * @return <code>true</code>, wenn die Daten angemeldet werden drfen, sonst <code>false</code>.
	 */
	@Deprecated
	boolean maySubscribeData(BaseSubscriptionInfo info, byte state);

	/**
	 * Prft, ob die angegebenen Daten beim Datenverteiler angemeldet werden drfen.
	 *
	 * @param info  Daten-Anmeldungs-Informationen
	 * @param action Art der Datenanmeldung
	 *
	 * @return <code>true</code>, wenn die Daten angemeldet werden drfen, sonst <code>false</code>.
	 */
	boolean maySubscribeData(BaseSubscriptionInfo info, UserAction action);

	/**
	 * Prft, ob die angegebenen Daten beim Datenverteiler angemeldet werden drfen.
	 *
	 * @param object Objekt, das verwendet wird
	 * @param attributeGroup Attributgruppe der Daten
	 * @param aspect Aspekt der Daten
	 * @param action Art der Datenanmeldung
	 * @return <code>true</code>, wenn die Daten angemeldet werden drfen, sonst <code>false</code>.
	 */
	boolean maySubscribeData(SystemObject object, AttributeGroup attributeGroup, Aspect aspect, UserAction action);


	/**
	 * Prft ob ein Objekt mit den angegeben Daten erstellt, verndert oder gelscht werden darf
	 * @param area Konfigurationsbereich
	 * @param type Typ des Objekts
	 * @return <code>true</code>, wenn das Objekt erstellt werden darf, sonst <code>false</code>.
	 */
	boolean mayCreateModifyRemoveObject(final ConfigurationArea area, final SystemObjectType type);

	/**
	 * Prft ob eine menge mit den angegebenen Daten verndert werden darf
	 * @param area Konfigurationsbereich
	 * @param type Typ des Objekts
	 * @return <code>true</code>, wenn das Objekt erstellt werden darf, sonst <code>false</code>.
	 */
	boolean mayModifyObjectSet(final ConfigurationArea area, final ObjectSetType type);

}
